---
name: Bug report
about: Create a report to help us improve napari-annotatorj
title: ''
labels: bug
assignees: spreka

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Desktop (please complete the following information):**
 - OS: [e.g. iOS]
 - Version [e.g. 22]

**napari setup (please complete the following information):**
- napari install type [e.g. pip, conda, binary release (please specify which extension e.g. .zip or .pkg/.exe)]
- napari version
- napari-annotatorj version
- (if relevant to your computer configuration i.e. your computer has CUDA-capable GPU and you set the plugin to use it)
    - CUDA + cuDNN versions
    - nVidia driver version
    - GPU type
    - torch version
    - tensorflow version

**Additional context**
Add any other context about the problem here.
